# Generated by Django 2.2.6 on 2020-01-18 19:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('avishan', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='TranslatableChar',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('en', models.CharField(blank=True, default=None, max_length=255, null=True)),
                ('fa', models.CharField(blank=True, default=None, max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
