# Generated by Django 3.0.5 on 2020-05-26 17:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('avishan', '0010_auto_20200401_1452'),
    ]

    operations = [
        migrations.AddField(
            model_name='requesttrack',
            name='request_data_size',
            field=models.BigIntegerField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='requesttrack',
            name='response_data_size',
            field=models.BigIntegerField(blank=True, default=None, null=True),
        ),
    ]
