# Generated by Django 3.0.3 on 2020-02-19 04:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('avishan', '0005_baseuser_language'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='email',
            name='is_verified',
        ),
        migrations.RemoveField(
            model_name='phone',
            name='is_verified',
        ),
        migrations.AddField(
            model_name='email',
            name='date_verified',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='phone',
            name='date_verified',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
    ]
